==> vtk6-6.3.0-5-aarch64.pkg.tar.xz: vtk/vtkGeoSource.java <==
// java wrapper for vtkGeoSource object
//

package vtk;
import vtk.*;

public class vtkGeoSource extends vtkObject
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native boolean FetchRoot_2(vtkGeoTreeNode id0);
  public boolean FetchRoot(vtkGeoTreeNode id0)
    { return FetchRoot_2(id0); }

  private native boolean FetchChild_3(vtkGeoTreeNode id0,int id1,vtkGeoTreeNode id2);
  public boolean FetchChild(vtkGeoTreeNode id0,int id1,vtkGeoTreeNode id2)
    { return FetchChild_3(id0,id1,id2); }

  private native void RequestChildren_4(vtkGeoTreeNode id0);
  public void RequestChildren(vtkGeoTreeNode id0)
    { RequestChildren_4(id0); }

  private native long GetRequestedNodes_5(vtkGeoTreeNode id0);
  public vtkCollection GetRequestedNodes(vtkGeoTreeNode id0) {
    long temp = GetRequestedNodes_5(id0);

    if (temp == 0) return null;
    return (vtkCollection)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void Initialize_6(int id0);
  public void Initialize(int id0)
    { Initialize_6(id0); }

  private native void ShutDown_7();
  public void ShutDown()
    { ShutDown_7(); }

  private native void WorkerThread_8();
  public void WorkerThread()
    { WorkerThread_8(); }

  private native long GetTransform_9();
  public vtkAbstractTransform GetTransform() {
    long temp = GetTransform_9();

    if (temp == 0) return null;
    return (vtkAbstractTransform)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  public vtkGeoSource() { super(); }

  public vtkGeoSource(long id) { super(id); }

}

==> vtk-8.2.0-3-aarch64.pkg.tar.xz: vtk/vtkGeoSource.java <==
// java wrapper for vtkGeoSource object
//

package vtk;
import vtk.*;

public class vtkGeoSource extends vtkObject
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native boolean FetchRoot_2(vtkGeoTreeNode id0);
  public boolean FetchRoot(vtkGeoTreeNode id0)
    { return FetchRoot_2(id0); }

  private native boolean FetchChild_3(vtkGeoTreeNode id0,int id1,vtkGeoTreeNode id2);
  public boolean FetchChild(vtkGeoTreeNode id0,int id1,vtkGeoTreeNode id2)
    { return FetchChild_3(id0,id1,id2); }

  private native void RequestChildren_4(vtkGeoTreeNode id0);
  public void RequestChildren(vtkGeoTreeNode id0)
    { RequestChildren_4(id0); }

  private native long GetRequestedNodes_5(vtkGeoTreeNode id0);
  public vtkCollection GetRequestedNodes(vtkGeoTreeNode id0) {
    long temp = GetRequestedNodes_5(id0);

    if (temp == 0) return null;
    return (vtkCollection)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void Initialize_6(int id0);
  public void Initialize(int id0)
    { Initialize_6(id0); }

  private native void ShutDown_7();
  public void ShutDown()
    { ShutDown_7(); }

  private native void WorkerThread_8();
  public void WorkerThread()
    { WorkerThread_8(); }

  private native long GetTransform_9();
  public vtkAbstractTransform GetTransform() {
    long temp = GetTransform_9();

    if (temp == 0) return null;
    return (vtkAbstractTransform)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkGeoSource() { super(); }

  public vtkGeoSource(long id) { super(id); }

}
